@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::authordeps 6.013; # TRIAL
+package Dist::Zilla::App::Command::authordeps 6.016; # TRIAL
 # ABSTRACT: List your distribution's author dependencies
 
 use Dist::Zilla::App -command;
@@ -16,6 +16,10 @@ use Dist::Zilla::App -command;
 #pod
 #pod   ; authordep Some::Package
 #pod
+#pod In order to add authordeps to all distributions that use a certain plugin bundle
+#pod (or plugin), just list them as prereqs of that bundle (e.g.: using
+#pod L<Dist::Zilla::Plugin::Prereqs> ).
+#pod
 #pod =cut
 
 sub abstract { "list your distribution's author dependencies" }
@@ -60,7 +64,7 @@ Dist::Zilla::App::Command::authordeps - List your distribution's author dependen
 
 =head1 VERSION
 
-version 6.013
+version 6.016
 
 =head1 SYNOPSIS
 
@@ -73,13 +77,17 @@ results by using special comments in the form:
 
   ; authordep Some::Package
 
+In order to add authordeps to all distributions that use a certain plugin bundle
+(or plugin), just list them as prereqs of that bundle (e.g.: using
+L<Dist::Zilla::Plugin::Prereqs> ).
+
 =head1 AUTHOR
 
 Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Ricardo SIGNES.
+This software is copyright (c) 2020 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
