@@ -1,8 +1,9 @@
-package Dist::Zilla::Plugin::GatherDir 6.013; # TRIAL
+package Dist::Zilla::Plugin::GatherDir 6.016; # TRIAL
 # ABSTRACT: gather all the files in a directory
 
 use Moose;
 use Dist::Zilla::Types qw(Path);
+use Dist::Zilla::Util;
 with 'Dist::Zilla::Role::FileGatherer';
 
 use namespace::autoclean;
@@ -12,7 +13,7 @@ use namespace::autoclean;
 #pod This is a very, very simple L<FileGatherer|Dist::Zilla::Role::FileGatherer>
 #pod plugin.  It looks in the directory named in the L</root> attribute and adds all
 #pod the files it finds there.  If the root begins with a tilde, the tilde is
-#pod replaced with the current user's home directory according to L<File::HomeDir>.
+#pod passed through C<glob()> first.
 #pod
 #pod Almost every dist will be built with one GatherDir plugin, since it's the
 #pod easiest way to get files from disk into your dist.  Most users just need:
@@ -175,7 +176,7 @@ sub gather_files {
 
   my $repo_root = $self->zilla->root;
   my $root = "" . $self->root;
-  $root =~ s{^~([\\/])}{require File::HomeDir; File::HomeDir::->my_home . $1}e;
+  $root =~ s{^~([\\/])}{ Dist::Zilla::Util->homedir . $1 }e;
   $root = path($root)->absolute($repo_root)->stringify if path($root)->is_relative;
 
   my $prune_regex = qr/\000/;
@@ -255,14 +256,14 @@ Dist::Zilla::Plugin::GatherDir - gather all the files in a directory
 
 =head1 VERSION
 
-version 6.013
+version 6.016
 
 =head1 DESCRIPTION
 
 This is a very, very simple L<FileGatherer|Dist::Zilla::Role::FileGatherer>
 plugin.  It looks in the directory named in the L</root> attribute and adds all
 the files it finds there.  If the root begins with a tilde, the tilde is
-replaced with the current user's home directory according to L<File::HomeDir>.
+passed through C<glob()> first.
 
 Almost every dist will be built with one GatherDir plugin, since it's the
 easiest way to get files from disk into your dist.  Most users just need:
@@ -339,7 +340,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Ricardo SIGNES.
+This software is copyright (c) 2020 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
