@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::UploadToCPAN 6.013; # TRIAL
+package Dist::Zilla::Plugin::UploadToCPAN 6.016; # TRIAL
 # ABSTRACT: upload the dist to CPAN
 
 use Moose;
@@ -7,6 +7,7 @@ with qw(Dist::Zilla::Role::BeforeRelease Dist::Zilla::Role::Releaser);
 use File::Spec;
 use Moose::Util::TypeConstraints;
 use Scalar::Util qw(weaken);
+use Dist::Zilla::Util;
 use Try::Tiny;
 
 use namespace::autoclean;
@@ -154,7 +155,7 @@ has pause_cfg_file => (
 #pod =attr pause_cfg_dir
 #pod
 #pod This is the directory for resolving a relative L</pause_cfg_file>.
-#pod It defaults to C<< File::HomeDir->my_home >>.
+#pod it defaults to the glob expansion of F<~>.
 #pod
 #pod =cut
 
@@ -162,7 +163,7 @@ has pause_cfg_dir => (
   is      => 'ro',
   isa     => 'Str',
   lazy    => 1,
-  default => sub { require File::HomeDir; File::HomeDir::->my_home },
+  default => sub { Dist::Zilla::Util->homedir },
 );
 
 #pod =attr pause_cfg
@@ -221,6 +222,32 @@ has upload_uri => (
   predicate => 'has_upload_uri',
 );
 
+#pod =attr retries
+#pod
+#pod The number of retries to perform on upload failure (5xx response). The default
+#pod is set to 3 by this plugin. This option will be passed to L<CPAN::Uploader>.
+#pod
+#pod =cut
+
+has retries => (
+  is => 'ro',
+  isa => 'Int',
+  default => 3,
+);
+
+#pod =attr retry_delay
+#pod
+#pod The number of seconds to wait between retries. The default is set to 5 seconds
+#pod by this plugin. This option will be passed to L<CPAN::Uploader>.
+#pod
+#pod =cut
+
+has retry_delay => (
+  is => 'ro',
+  isa => 'Int',
+  default => 5,
+);
+
 has uploader => (
   is   => 'ro',
   isa  => 'CPAN::Uploader',
@@ -239,6 +266,10 @@ has uploader => (
            ? (subdir => $self->subdir) : ()),
       ($self->has_upload_uri
            ? (upload_uri => $self->upload_uri) : ()),
+      ($self->retries
+           ? (retries => $self->retries) : ()),
+      ($self->retry_delay
+           ? (retry_delay => $self->retry_delay) : ()),
     });
 
     $uploader->{'Dist::Zilla'}{plugin} = $self;
@@ -284,7 +315,7 @@ Dist::Zilla::Plugin::UploadToCPAN - upload the dist to CPAN
 
 =head1 VERSION
 
-version 6.013
+version 6.016
 
 =head1 SYNOPSIS
 
@@ -340,7 +371,7 @@ L</pause_cfg_dir>.
 =head2 pause_cfg_dir
 
 This is the directory for resolving a relative L</pause_cfg_file>.
-It defaults to C<< File::HomeDir->my_home >>.
+it defaults to the glob expansion of F<~>.
 
 =head2 pause_cfg
 
@@ -359,13 +390,23 @@ If given, this specifies an alternate URI for the PAUSE upload form.  By
 default, the default supplied by L<CPAN::Uploader> is used.  Using this option
 is not recommended in most cases.
 
+=head2 retries
+
+The number of retries to perform on upload failure (5xx response). The default
+is set to 3 by this plugin. This option will be passed to L<CPAN::Uploader>.
+
+=head2 retry_delay
+
+The number of seconds to wait between retries. The default is set to 5 seconds
+by this plugin. This option will be passed to L<CPAN::Uploader>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Ricardo SIGNES.
+This software is copyright (c) 2020 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
